@@ -13,7 +13,7 @@ impl Plugin for BarPlugin {
         app.add_system_set(
             SystemSet::on_update(NotationAssetsStates::Loaded)
                 .with_system(BarView::do_layout.system())
-                .with_system(BarView::update_number_text.system())
+                .with_system(BarView::update_number_text.system()),
         );
     }
 }
