@@ -1,13 +1,19 @@
-use std::{fmt::Display, sync::Arc};
+use std::fmt::Display;
+use std::sync::Arc;
 
 use bevy::prelude::*;
-use notation_bevy_utils::prelude::{BevyUtil, GridData, GridView, LayoutAnchor, LayoutQuery, LayoutSize, View, ViewBundle, ViewQuery, DockPanel, DockSide, LayoutConstraint, ColorBackground};
+use notation_bevy_utils::prelude::{
+    BevyUtil, ColorBackground, DockPanel, DockSide, GridData, GridView, LayoutAnchor,
+    LayoutConstraint, LayoutQuery, LayoutSize, View, ViewBundle, ViewQuery,
+};
 use notation_midi::prelude::PlayControlEvent;
 use notation_model::prelude::{PlayState, Tab};
 
-use crate::{prelude::{NotationAppState, NotationAssets, NotationSettings, NotationTheme}, ui::layout::NotationLayout};
+use crate::prelude::{NotationAppState, NotationAssets, NotationSettings, NotationTheme};
+use crate::ui::layout::NotationLayout;
 
-use super::{play_button::{PlayButton, PlayButtonShape}, play_plugin::PlayPanelDoLayoutEvent};
+use super::play_button::{PlayButton, PlayButtonShape};
+use super::play_plugin::PlayPanelDoLayoutEvent;
 
 pub struct PlayPanel {
     pub playing: bool,
@@ -22,7 +28,10 @@ impl Display for PlayPanel {
 
 impl Default for PlayPanel {
     fn default() -> Self {
-        Self { playing: false, should_loop: true }
+        Self {
+            playing: false,
+            should_loop: true,
+        }
     }
 }
 
@@ -76,8 +85,7 @@ impl PlayPanel {
         tab: &Arc<Tab>,
     ) -> Entity {
         let panel = PlayPanel::default();
-        let panel_entity =
-            BevyUtil::spawn_child_bundle(commands, entity, ViewBundle::from(panel));
+        let panel_entity = BevyUtil::spawn_child_bundle(commands, entity, ViewBundle::from(panel));
         ColorBackground::spawn(
             commands,
             panel_entity,
@@ -85,7 +93,15 @@ impl PlayPanel {
             theme.colors.ui.control_background,
         );
         for i in 0..=5 {
-            PlayButton::spawn(commands, assets, theme, settings, panel_entity, tab, (i as usize).into());
+            PlayButton::spawn(
+                commands,
+                assets,
+                theme,
+                settings,
+                panel_entity,
+                tab,
+                (i as usize).into(),
+            );
         }
         panel_entity
     }
@@ -98,7 +114,9 @@ impl PlayPanel {
         mut layout_query: LayoutQuery,
         cell_query: ViewQuery<PlayButton>,
     ) {
-        if theme._bypass_systems { return; }
+        if theme._bypass_systems {
+            return;
+        }
         let engine = NotationLayout::new(&theme, &state, &settings);
         for evt in evts.iter() {
             evt.view.do_layout(
@@ -117,23 +135,44 @@ impl PlayPanel {
         mut evts: EventReader<PlayControlEvent>,
         mut shape_query: Query<(Entity, &mut PlayButtonShape)>,
     ) {
-        if theme._bypass_systems { return; }
+        if theme._bypass_systems {
+            return;
+        }
         for evt in evts.iter() {
             match evt {
-                PlayControlEvent::OnTick {position: _, tick_result} => {
+                PlayControlEvent::OnTick {
+                    position: _,
+                    tick_result,
+                } => {
                     if tick_result.stopped {
                         let play_state = PlayState::Stopped;
-                        PlayButton::on_play_state(&mut commands, &theme, &mut shape_query, &play_state);
+                        PlayButton::on_play_state(
+                            &mut commands,
+                            &theme,
+                            &mut shape_query,
+                            &play_state,
+                        );
                     }
                 }
                 PlayControlEvent::OnPlayState(play_state) => {
                     PlayButton::on_play_state(&mut commands, &theme, &mut shape_query, play_state);
                 }
                 PlayControlEvent::OnShouldLoop(should_loop) => {
-                    PlayButton::on_should_loop(&mut commands, &theme, &mut shape_query, *should_loop);
+                    PlayButton::on_should_loop(
+                        &mut commands,
+                        &theme,
+                        &mut shape_query,
+                        *should_loop,
+                    );
                 }
                 PlayControlEvent::OnBeginEnd(begin_bar_ordinal, end_bar_ordinal) => {
-                    PlayButton::on_begin_end(&mut commands, &theme, &mut shape_query, *begin_bar_ordinal, *end_bar_ordinal)
+                    PlayButton::on_begin_end(
+                        &mut commands,
+                        &theme,
+                        &mut shape_query,
+                        *begin_bar_ordinal,
+                        *end_bar_ordinal,
+                    )
                 }
                 PlayControlEvent::OnSpeedFactor(_) => {}
             }
