@@ -40,14 +40,10 @@ impl Default for GuitarTheme {
             string_y_factor: 0.5, //0.466,
             fret_y_factors: [
                 //0
-                0.476, 0.425, 0.369, 0.315, 0.264,
-                //5
-                0.217, 0.172, 0.130, 0.090, 0.051,
-                //10
-                0.016, -0.018, -0.051, -0.080, -0.108,
-                //15
-                -0.135, -0.1605, -0.184, -0.206, -0.227,
-                //20
+                0.476, 0.425, 0.369, 0.315, 0.264, //5
+                0.217, 0.172, 0.130, 0.090, 0.051, //10
+                0.016, -0.018, -0.051, -0.080, -0.108, //15
+                -0.135, -0.1605, -0.184, -0.206, -0.227, //20
                 -0.247, -0.267, -0.286,
             ],
             capo_width_factor: 0.78,
