@@ -1,7 +1,7 @@
 use bevy::prelude::*;
 
 use notation_bevy_utils::prelude::ShapeOp;
-use notation_model::prelude::{LaneEntry, Tone, Entry};
+use notation_model::prelude::{Entry, LaneEntry, Tone};
 
 use crate::prelude::{EntryPlaying, NotationAssets, NotationSettings, NotationTheme};
 
@@ -29,7 +29,13 @@ pub fn create_tone_notes(
             let data = ToneNoteData::new(entry, ToneNoteValue::new(&bar, note, mode));
             let note_entity = data.create(commands, theme, entity);
             if settings.show_melody_syllable && !entry.prev_is_tie() {
-                theme.texts.melody.spawn_syllable_text(commands, note_entity, assets, settings, &data.value.syllable())
+                theme.texts.melody.spawn_syllable_text(
+                    commands,
+                    note_entity,
+                    assets,
+                    settings,
+                    &data.value.syllable(),
+                )
             }
         }
     }
@@ -41,7 +47,9 @@ pub fn on_entry_playing_changed(
     query: Query<(Entity, &EntryPlaying, &Children), Changed<EntryPlaying>>,
     mut note_query: Query<(Entity, &mut ToneNoteData)>,
 ) {
-    if theme._bypass_systems { return; }
+    if theme._bypass_systems {
+        return;
+    }
     for (_entity, playing, children) in query.iter() {
         for child in children.iter() {
             if let Ok((entity, mut data)) = note_query.get_mut(*child) {
